==> vue-picker-column-2.8.0.tgz: package/lib/index.js <==
import { renderless, api } from "@dftvue2-opentiny/vue-renderless/picker-column/vue";
import { defineComponent, $prefix, setup as _setup } from "@dftvue2-opentiny/vue-common";
function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  if (functionalTemplate) {
    options.functional = true;
  }
  if (scopeId) {
    options._scopeId = "data-v-" + scopeId;
  }
  var hook;
  if (moduleIdentifier) {
    hook = function hook2(context) {
      context = context || // cached call
      this.$vnode && this.$vnode.ssrContext || // stateful
      this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext;
      if (!context && typeof __VUE_SSR_CONTEXT__ !== "undefined") {
        context = __VUE_SSR_CONTEXT__;
      }
      if (injectStyles) {
        injectStyles.call(this, context);
      }
      if (context && context._registeredComponents) {
        context._registeredComponents.add(moduleIdentifier);
      }
    };
    options._ssrRegister = hook;
  } else if (injectStyles) {
    hook = shadowMode ? function() {
      injectStyles.call(this, (options.functional ? this.parent : this).$root.$options.shadowRoot);
    } : injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

import "@dftvue2-opentiny/vue-theme-mobile/picker-column/index.css";
var __vue2_script = defineComponent({
  name: $prefix + "PickerColumn",
  emits: ["change"],
  props: {
    columnsItem: {
      type: Object,
      default: function _default() {
        return {};
      }
    },
    defaultIndex: Number,
    itemHeight: Number,
    visibleItemCount: Number,
    swipeDuration: Number,
    valueKey: String
  },
  setup: function setup(props, context) {
    return _setup({
      props,
      context,
      renderless,
      api,
      mono: true
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    staticClass: "tiny-mobile-picker-column"
  }, [_c("div", {
    staticClass: "tiny-mobile-picker-column__mask",
    style: _vm.state.maskStyle
  }), _c("div", {
    staticClass: "tiny-mobile-picker-column__indicator",
    style: {
      height: _vm.itemHeight + "px"
    }
  }), _c("ul", {
    ref: "track",
    staticClass: "tiny-mobile-picker-column__wrapper",
    style: _vm.state.wrapperStyle,
    on: {
      "click": function click($event) {
        return _vm.onClickItem(1);
      }
    }
  }, _vm._l(_vm.state.columnsItem.values, function(item, index) {
    return _c("li", {
      key: index,
      class: {
        "tiny-mobile-picker-column__item": true,
        "is-select": index === _vm.state.currentIndex
      },
      style: {
        height: _vm.itemHeight + "px",
        lineHeight: _vm.itemHeight + "px"
      },
      on: {
        "click": function click($event) {
          $event.stopPropagation();
          return _vm.onClickItem(index);
        },
        "transitionend": _vm.onTransitionEnd
      }
    }, [_vm._v(" " + _vm._s(item) + " ")]);
  }), 0)]);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles, null, null, null);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var PickerColumn = /* @__PURE__ */ function() {
  return __component__.exports;
}();
var version = "2.8.0";
PickerColumn.install = function(Vue) {
  Vue.component(PickerColumn.name, PickerColumn);
};
PickerColumn.version = version;
export {
  PickerColumn as default
};

==> vue-picker-column-2.21.0.tgz: package/lib/index.js <==
import { renderless, api } from '@opentinyvue/vue-renderless/picker-column/vue';
import { defineComponent, $prefix, setup } from '@opentinyvue/vue-common';
import '@opentinyvue/vue-theme-mobile/picker-column/index.css';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  name: $prefix + "PickerColumn",
  emits: ["change"],
  props: {
    columnsItem: {
      type: Object,
      default: function _default() {
        return {};
      }
    },
    defaultIndex: Number,
    itemHeight: Number,
    visibleItemCount: Number,
    swipeDuration: Number,
    valueKey: String
  },
  setup: function setup$1(props, context) {
    return setup({
      props,
      context,
      renderless,
      api,
      mono: true
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    staticClass: "tiny-mobile-picker-column"
  }, [_c("div", {
    staticClass: "tiny-mobile-picker-column__mask",
    style: _vm.state.maskStyle
  }), _c("div", {
    staticClass: "tiny-mobile-picker-column__indicator",
    style: {
      height: _vm.itemHeight + "px"
    }
  }), _c("ul", {
    ref: "track",
    staticClass: "tiny-mobile-picker-column__wrapper",
    style: _vm.state.wrapperStyle,
    on: {
      "click": function click($event) {
        return _vm.onClickItem(1);
      }
    }
  }, _vm._l(_vm.state.columnsItem.values, function(item, index) {
    return _c("li", {
      key: index,
      class: {
        "tiny-mobile-picker-column__item": true,
        "is-select": index === _vm.state.currentIndex
      },
      style: {
        height: _vm.itemHeight + "px",
        lineHeight: _vm.itemHeight + "px"
      },
      on: {
        "click": function click($event) {
          $event.stopPropagation();
          return _vm.onClickItem(index);
        },
        "transitionend": _vm.onTransitionEnd
      }
    }, [_vm._v(" " + _vm._s(item) + " ")]);
  }), 0)]);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var PickerColumn = /* @__PURE__ */ function() {
  return __component__.exports;
}();
var version = "2.21.0";
PickerColumn.install = function(Vue) {
  Vue.component(PickerColumn.name, PickerColumn);
};
PickerColumn.version = version;

export { PickerColumn as default };
